<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Misc</name>
    <message>
        <location filename="../Misc.js" line="+60"/>
        <source>Misc Tools</source>
        <translation>Různé nástroje</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show misc tools</source>
        <translation>Zobrazit různé nástroje</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Misc</source>
        <translation>Různé</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Misc</source>
        <translation>&amp;Různé</translation>
    </message>
</context>
</TS>
